R/04_validation_functions.R
data_summary.Rd
data_summary is used to to calculate the mean, standard deviation and 95% credible interval.
data_summary
data_summary(data, varname, groupnames)
Data frame.
Name of a column containing the variable.
Vector of column names to be used as grouping variables.
A data frame containing the posterior output.