decision_model implements the decision model used.
decision_model(l_params_all, err_stop = FALSE, verbose = FALSE)
Arguments
- l_params_all
List with all parameters of decision model
- err_stop
Logical variable to stop model run if set up as TRUE. Default = FALSE.
- verbose
Logical variable to indicate print out of messages. Default = FALSE
Value
The transition probability array and the cohort trace matrix.