load_all_params loads all parameters for the decision model from multiple sources and creates a list.

load_all_params(file.init = NULL, file.mort = NULL)

Arguments

file.init

String with the location and name of the file with initial set of parameters. If NULL, df_params_init will be used as default

file.mort

String with the location and name of the file with mortality data. If NULL, all_cause_mortality will be used as default

Value

A list of all parameters used for the decision model.

Examples

l_params_all <- load_all_params()
str(l_params_all)
#> List of 28
#>  $ v_names_str    : chr [1:2] "No Treatment" "Treatment"
#>  $ n_str          : int 2
#>  $ n_age_init     : int 25
#>  $ n_t            : int 75
#>  $ v_age_names    : int [1:76] 25 26 27 28 29 30 31 32 33 34 ...
#>  $ v_n            : chr [1:4] "H" "S1" "S2" "D"
#>  $ n_states       : int 4
#>  $ v_s_init       : Named num [1:4] 1 0 0 0
#>   ..- attr(*, "names")= chr [1:4] "H" "S1" "S2" "D"
#>  $ v_r_mort_by_age: num [1:111, 1] 0.005907 0.000402 0.000253 0.000196 0.000147 ...
#>   ..- attr(*, "dimnames")=List of 2
#>   .. ..$ : NULL
#>   .. ..$ : chr "Total"
#>  $ c_H            : int 2000
#>  $ c_S1           : int 4000
#>  $ c_S2           : int 15000
#>  $ c_D            : int 0
#>  $ c_Trt          : int 12000
#>  $ u_H            : int 1
#>  $ u_S1           : num 0.75
#>  $ u_S2           : num 0.5
#>  $ u_D            : int 0
#>  $ u_Trt          : num 0.95
#>  $ p_HS1          : num 0.15
#>  $ p_S1H          : num 0.5
#>  $ p_S1S2         : num 0.105
#>  $ hr_S1          : int 3
#>  $ hr_S2          : int 10
#>  $ n_age_init     : int 25
#>  $ n_t            : int 75
#>  $ d_c            : num 0.03
#>  $ d_e            : num 0.03