log_post Computes a log-posterior value for one (or multiple) parameter set(s) based on the simulation model, likelihood functions and prior distributions.

log_post(
  v_params,
  l_params_all = load_all_params(),
  v_param_names = c("p_S1S2", "hr_S1", "hr_S2"),
  v_lb = c(p_S1S2 = 0.01, hr_S1 = 1, hr_S2 = 5),
  v_ub = c(p_S1S2 = 0.5, hr_S1 = 4.5, hr_S2 = 15),
  v_weights = NULL
)

Arguments

v_params

Vector (or matrix) of model parameters.

l_params_all

List with all parameters of the decision model.

v_param_names

Vector with parameter names.

v_lb

Vector with lower bounds for each parameter.

v_ub

Vector with upper bounds for each parameter.

v_weights

Numeric vector with one weight per calibration target, used to compute the overall log-likelihood as a weighted sum of the target-specific log-likelihoods. If NULL (default), all targets get an equal weight of one.

Value

A scalar (or vector) with log-posterior values.

Examples

# \donttest{
  v_param_names  <- c("p_S1S2", "hr_S1", "hr_S2")
  n_param        <- length(v_param_names)
  v_lb <- c(p_S1S2 = 0.01, hr_S1 = 1.0, hr_S2 = 5)  # lower bound
  v_ub <- c(p_S1S2 = 0.50, hr_S1 = 4.5, hr_S2 = 15) # upper bound
  v_target_names <- c("Surv", "Prev", "PropSicker")
  n_target       <- length(v_target_names)
  log_post(v_params = sample_prior(n_samp = 5))
#> [1] -121.05411 -365.83556   16.46938 -288.30372   17.36006
# }