open_guide opens the bookdown user guide of the framework. The guide is built from the report directory of the darthpack repository, so it is available when the repository is used as a coding template (for instance after devtools::load_all(".")). When darthpack is used as an installed package the guide is not part of the installation, and this function opens the online version instead.

open_guide(ext = "html", online = FALSE)

Arguments

ext

Extension of the book to open: 'html' or 'pdf'

online

Logical variable to open the online version of the guide rather than looking for a local copy. Default = FALSE

Value

Invisibly, the URL or path that was opened.

Examples

if (FALSE) { # \dontrun{
  open_guide()
  open_guide("pdf")
} # }