An object of class psa with PSA inputs and outputs for the Sick-Sicker model.
l_psaA list with 9 elements:
Number of strategies.
Strategy names.
Number of PSA samples.
A data frame with n_sim rows and n_strategies columns with the cost per strategy for all PSA samples.
A data frame with n_sim rows and n_strategies columns with the effectiveness per strategy for all PSA samples.
An optional third outcome, NULL here.
A data frame of input parameters with
n_sim rows and 15 columns:
hr_S1: Hazard rate ratio of death in S1 vs H
hr_S2: Hazard rate ratio of death in S2 vs H
p_HS1: Annual transition probability of disease onset (H to S1)
p_S1H: Annual transition probability of recovery (S1 to H)
c_H: Annual cost for healthy individuals
c_S1: Annual cost for sick individuals in S1
c_S2: Annual cost for sicker individuals in S2
c_Trt: Additional costs of sick individuals treated in S1 or S2
c_D: Annual cost for dead individuals
u_H: Utility for healthy individuals
u_S1: Utility for sick individuals in S1
u_S2: Utility for sicker individuals in S2
u_D: Utility for dead individuals
u_Trt: Utility for treated individuals in S1
The first three are drawn from the posterior distribution of the calibrated
parameters; the rest are sampled from the distributions that characterize
their uncertainty. The parameters that are not varied in the
probabilistic analysis (n_age_init, n_t, d_c and
d_e) are not part of this data frame.
A vector of strings with parameter names.
A string with the currency.