R/03_calibration_functions.R
sample_prior.Rdsample_prior generates a sample of parameter sets from their prior
distribution.
A matrix with n_samp rows and one column per calibrated parameter.
Each row corresponds to a parameter set sampled from their prior
distributions.
v_param_names <- c("p_S1S2", "hr_S1", "hr_S2")
n_param <- length(v_param_names)
v_lb <- c(p_S1S2 = 0.01, hr_S1 = 1.0, hr_S2 = 5) # lower bound
v_ub <- c(p_S1S2 = 0.50, hr_S1 = 4.5, hr_S2 = 15) # upper bound
sample_prior(2)
#> p_S1S2 hr_S1 hr_S2
#> [1,] 0.07127372 1.854710 13.383206
#> [2,] 0.30519044 4.255687 5.438924